//+------------------------------------------------------------------+
//|                                                   FiboExpert.mq4 |
//|          Copyright  2007, PHK Corporation. All rights reserved. |
//|                                 http://forexhyipclub.phkcorp.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2007, PHK Corporation. All rights reserved."
#property link      "http://forexhyipclub.phkcorp.com"

#include <stdlib.mqh>

#define  LookBack             200 	// The historical number of bars to use for analysis
#define  RetracementWindow    5 	   // The number of points the price must come within, also used for stoploss and takeprofit
#define  RetracementFactor    2.0   // A multiple of the RetracementWindow that the price must bounce or pierce
#define  Slippage             3		// The amount of slippage alowwed in the price

int  gFlag62 = 0; 			// Global flag used to indicate trade setup
int  gFlag50 = 0; 			// Global flag used to indicate trade setup
int  gFlag38 = 0;				// Global flag used to indicate trade setup

int iHH = 0; 				// The index of the Highest high in the lookback period
double HighestHigh = 0; // The price of the Highest high in the lookback period
int iLL = 0;				// The index of the LowestLow low in the lookback period
double LowestLow = 0;	// The price of the LowestLow low in the lookback period

double fibLevel62 =  0.0; 		// The Finonacci 62% retracement level
double fibLevel50 =  0.0; 		// The Finonacci 50% retracement level
double fibLevel38 =  0.0;		// The Finonacci 38% retracement level


extern double  Lots = 0.1;

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//----
	// Need enough bars on chart to make accurate calculation
	if ( Bars < LookBack ) {
	   Print("Not enough bars on chart to make accurate calculation");
		return;
	}

   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
//----
	// Only allow one open trade at a time, exit if a trade is already opened
	if( OrdersTotal() > 0 ) {
	   Print("Only allow one open trader at a time, exit if a trade is already opened");
		return;
	}

	// 1. The Market Setup
	// Market Setup:  The currency pair has made a new high (or low).
	// Find the Highhset High in the Lookback Period
	
	
	iHH = Highest(NULL, 0, MODE_HIGH, LookBack, 0 );
	HighestHigh = High[iHH];
	iLL = Lowest( NULL, 0, MODE_LOW, LookBack, 0 );
	LowestLow = Low[iLL];
	
	
	// If the market has reached a new high, recalculate the fib levels 
	if( Bid > HighestHigh ) {
		fibLevel62 = ((HighestHigh - LowestLow)*0.618) + LowestLow;
		fibLevel50 = ((HighestHigh - LowestLow)*0.500) + LowestLow;
		fibLevel38 = ((HighestHigh - LowestLow)*0.382) + LowestLow;
	}
	
	
	// 2. The Trade Setup	
	// Trade Setup: After the new high, the currency pair has begun 
	// to retrace towards a Fibonacci retracement level.  (This level 
	// may or may not align with retracement levels of other time frames.)
	 
	gFlag38=0; gFlag50=0; gFlag62=0;
	
	if( Bid - (RetracementWindow*Point) <= fibLevel62 ) {
		gFlag62=1;
	}
	
	if( Bid - (RetracementWindow*Point) <= fibLevel50 ) {
		gFlag50=1;
	}
	
	if( Bid - (RetracementWindow*Point) <= fibLevel38 ) {
		gFlag38=1;
	}

   Print("Retracement window=",RetracementWindow*Point);
	
	
	// 4. The Trade Trigger
	// Trade Trigger:  The currency pair has reached the retracement 
	// level and has confirmed that the price as either (i) pierced the 
	// level, or (ii) bounced off the level.
	
	
	// Pierced the 62 Level
	if(   (gFlag62 == 1) && 
	      (Close[0] > fibLevel62+(RetracementFactor*RetracementWindow*Point)) && 
	      (Ask < HighestHigh)) {
		// BUY 62
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(),OP_BUY, Lots, Ask, Slippage, fibLevel62-(RetracementWindow*Point), HighestHigh, "FiboExpert", 0, 0, Blue );
		
	}
	
	// Bounced off the 62 Level
   if( 	(gFlag62 == 1 ) && 
         (Close[0] < fibLevel62+(RetracementFactor*RetracementWindow*Point)) &&
			(Bid > fibLevel50)) {
		// SELL 62
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(), OP_SELL, Lots, Bid, Slippage, fibLevel62+(RetracementWindow*Point), fibLevel50, "FiboExpert", 0, 0, Red );
	}


	// Pierced the 50 Level
	if( 	(gFlag50 == 1 ) && 
			(Close[0] > fibLevel62+(RetracementFactor*RetracementWindow*Point)) &&
			(Ask < 	fibLevel62)) {
		// BUY 50
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(), OP_BUY, Lots, Ask, Slippage, fibLevel50-(RetracementWindow*Point), fibLevel62, "FiboExpert", 0, 0, Blue );
		return(0);
	}
	
	// Bounced off the 50 Level
	if( 	(gFlag50 == 1 ) && 
			(Close[0] < fibLevel62+(RetracementFactor*RetracementWindow*Point)) &&
			(Bid > fibLevel38)) {
		// SELL 50
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(), OP_SELL, Lots, Bid, Slippage, fibLevel50+(RetracementWindow*Point), fibLevel38, "FiboExpert", 0, 0, Red );
		return(0);
	}


	// Pierced the 38 Level
	if( 	(gFlag38 == 1 )	 &&
			(Close[0] > fibLevel62+(RetracementFactor*RetracementWindow*Point)) &&
			(Ask < 	LowestLow)) {
		// BUY 38
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(), OP_BUY, Lots, Ask, Slippage, fibLevel38-(RetracementWindow*Point), LowestLow, "FiboExpert", 0, 0, Blue );
		return(0);
	}

	// Bounced off the 38 Level
	if( 	(gFlag38 == 1 ) && 
			(Close[0] < fibLevel62+(RetracementFactor*RetracementWindow*Point)) &&
			(Bid > fibLevel50)) {
		// SELL 38
		gFlag38=0; gFlag50=0; gFlag62=0;
		OrderSend(Symbol(), OP_SELL, Lots, Bid, Slippage, fibLevel38+(RetracementWindow*Point), fibLevel50, "FiboExpert", 0, 0, Red );
		return(0);
	}
   
//----
   return(0);
  }
//+------------------------------------------------------------------+


